@@ -36,7 +36,7 @@ class ArtifactEntry:
         self.status = status
 
     # ArtifactEntry 객체를 기반으로 파일 다운로드 수행
-    def download(self, local_root_path: str, artifact_id: int, file_index: int, total_file_count:int ):
+    def download(self, local_root_path: str, artifact_id: int, team_name: str, exp_name: str, artifact_name: str, artifact_type: str, file_index: int, total_file_count:int ):
         assert_that(local_root_path).is_not_none()
         assert_that(artifact_id).is_not_none()
 
@@ -45,7 +45,7 @@ class ArtifactEntry:
         i_last_separator = len(local_path) - local_path[::-1].find(os.path.sep) - 1
         Path(local_path[:i_last_separator]).mkdir(parents=True, exist_ok=True)
 
-        interface.download_file(self.path, artifact_id, local_path, file_index, total_file_count, self.size)
+        interface.download_file(self.path, artifact_id, local_path, team_name, exp_name, artifact_name, artifact_type, file_index, total_file_count, self.size)
 
         # 다운로드 완료 후 local_path 설정
         self.local_path = local_path
@@ -189,7 +189,7 @@ class Artifacts:
 
         # Artifact 객체가 가진 entry_list 의  ArtifactEntry.download()를 각각 호출
         for idx, entry in enumerate(self.entry_list):
-            entry.download(local_root_path, self.id, idx, total_file_count=len(self.entry_list))
+            entry.download(local_root_path, self.id, self.run.team_name, self.run.exp_name, self.name, self.type, idx, total_file_count=len(self.entry_list))
         return local_root_path
 
     def __str__(self) -> str:
