@@ -4,7 +4,7 @@ from typing import Dict
 from deepdriver.sdk.data_types.run import set_run, Run
 from deepdriver.sdk.interface import interface
 
-logger = logging.getLogger("deepdriver")
+from deepdriver import logger
 
 # 실행과 실험환경을 만드는 함수
 def init(exp_name: str="", team_name: str="", run_name: str="", config: Dict=None) -> Run:
