@@ -110,9 +110,9 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
 
             chunk_bytes = file.read(CHUNK_SIZE)
             uploaded_size += len(chunk_bytes)
-            util.print_progress(uploaded_size, total_size, f'Uploading: [{local_path}]', f"[{file_index + 1}/{len(entry_list)}]")
+            util.print_progress(uploaded_size, total_size, f'Uploading: [{local_path}]', f"[{file_index + 1}/{1 if len(entry_list) == 0 else len(entry_list)}")
             if len(chunk_bytes) == 0: # Reached EOF
-                util.print_progress(total_size, total_size, f'Uploading: [{local_path}]',f"[{file_index + 1}/{len(entry_list)}]")  # 100%
+                util.print_progress(total_size, total_size, f'Uploading: [{local_path}]',f"[{file_index + 1}/{1 if len(entry_list) == 0 else len(entry_list)}]")  # 100%
                 return
             yield UploadFileRequest(
                 file=FileRecord(file=FileItem(
@@ -154,13 +154,17 @@ def save_file(file_path: str, file_index: int, total_file_count: int, file_size:
     return None
 
 
-def download_file(path: str, artifact_id: int, local_path: str, file_index: int, total_file_count: int,
+def download_file(path: str, artifact_id: int, local_path: str, team_name: str, exp_name: str, artifact_name: str, artifact_type: str, file_index: int, total_file_count: int,
                       file_size: int):
     # TODO 응답에 digest 값을 받아 추후 각 파일에 대한 정합성 체크시 활용한다.
     save_file(local_path, file_index, total_file_count, file_size, get_stub().download_file(DownloadFileRequest(
         path=path,
         artifact_id=artifact_id,
         authorization=http_interface.get_jwt_key(),
+        teamName = team_name,
+        expName = exp_name,
+        artifactName = artifact_name,
+        artifactType = artifact_type,
     )))
 
 def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, teamName: str, expName: str,  entry_list: List[ArtifactEntry]) -> int:
